@@ -16,9 +16,6 @@
 //! `queue-file` crate is a feature complete and binary compatible port of `QueueFile` class from
 //! Tape2 by Square, Inc. Check the original project [here](https://github.com/square/tape).
 
-// `error_chain!` can recurse deeply
-#![recursion_limit = "1024"]
-
 #[cfg(test)]
 extern crate pretty_assertions;
 
@@ -191,7 +188,7 @@ impl QueueFile {
         file.seek(SeekFrom::Start(0))?;
         let bytes_read = file.read(&mut buf)?;
 
-        ensure!(bytes_read >= 32, CorruptedFile { msg: "file too short" });
+        ensure!(bytes_read >= 32, CorruptedFileSnafu { msg: "file too short" });
 
         let versioned = !force_legacy && (buf[0] & 0x80) != 0;
 
@@ -208,7 +205,7 @@ impl QueueFile {
 
             let version = buf.get_u32() & 0x7FFF_FFFF;
 
-            ensure!(version == 1, UnsupportedVersion { detected: version, supported: 1u32 });
+            ensure!(version == 1, UnsupportedVersionSnafu { detected: version, supported: 1u32 });
 
             file_len = buf.get_u64();
             elem_cnt = buf.get_u32() as usize;
@@ -235,19 +232,19 @@ impl QueueFile {
 
         let real_file_len = file.metadata()?.len();
 
-        ensure!(file_len <= real_file_len, CorruptedFile {
+        ensure!(file_len <= real_file_len, CorruptedFileSnafu {
             msg: format!(
                 "file is truncated. expected length was {} but actual length is {}",
                 file_len, real_file_len
             )
         });
-        ensure!(file_len >= header_len, CorruptedFile {
+        ensure!(file_len >= header_len, CorruptedFileSnafu {
             msg: format!("length stored in header ({}) is invalid", file_len)
         });
-        ensure!(first_pos <= file_len, CorruptedFile {
+        ensure!(first_pos <= file_len, CorruptedFileSnafu {
             msg: format!("position of the first element ({}) is beyond the file", first_pos)
         });
-        ensure!(last_pos <= file_len, CorruptedFile {
+        ensure!(last_pos <= file_len, CorruptedFileSnafu {
             msg: format!("position of the last element ({}) is beyond the file", last_pos)
         });
 
@@ -303,11 +300,11 @@ impl QueueFile {
 
     /// Adds an element to the end of the queue.
     pub fn add(&mut self, buf: &[u8]) -> Result<()> {
-        ensure!(self.elem_cnt + 1 < i32::max_value() as usize, TooManyElements {});
+        ensure!(self.elem_cnt + 1 < i32::max_value() as usize, TooManyElementsSnafu {});
 
         let len = buf.len();
 
-        ensure!(len <= i32::max_value() as usize, ElementTooBig {});
+        ensure!(len <= i32::max_value() as usize, ElementTooBigSnafu {});
 
         self.expand_if_necessary(len)?;
 
@@ -765,7 +762,7 @@ mod tests {
     fn gen_rand_file_name() -> String {
         let mut rng = thread_rng();
         let mut file_name =
-            iter::repeat(()).map(|()| rng.sample(Alphanumeric)).take(16).collect::<String>();
+            iter::repeat(()).map(|()| rng.sample(Alphanumeric)).map(char::from).take(16).collect::<String>();
 
         file_name.push_str(".qf");
 
@@ -900,10 +897,10 @@ mod tests {
     {
         let mut rng = thread_rng();
 
-        let n = rng.gen_range(min_n, max_n);
+        let n = rng.gen_range(min_n..max_n);
 
         for _ in 0..n {
-            let data_size = rng.gen_range(min_data_size, max_data_size);
+            let data_size = rng.gen_range(min_data_size..max_data_size);
             let data = gen_rand_data(data_size);
 
             assert_eq!(qf.add(data.as_ref()).is_ok(), true);
@@ -920,7 +917,7 @@ mod tests {
             return 0;
         }
 
-        let n = if qf.size() == 1 { 1 } else { thread_rng().gen_range(min_n, max_n) };
+        let n = if qf.size() == 1 { 1 } else { thread_rng().gen_range(min_n..max_n) };
 
         for _ in 0..n {
             let d0 = q.pop_front().unwrap();
